@@ -60,9 +60,9 @@ struct BBDATA
          'U' - non-basic variable on its upper bound
          'F' - non-basic free variable
          'S' - non-basic fixed variable */
-      POOL *node_pool;
+      DMP *node_pool;
       /* memory pool for BBNODE objects */
-      POOL *tagx_pool;
+      DMP *tagx_pool;
       /* memory pool for BBTAGX objects */
       BBNODE *root;
       /* pointer to the root node */
