@@ -26,22 +26,22 @@
 #ifndef _GLPIMG_H
 #define _GLPIMG_H
 
-#define create_img            _glp_create_img
-#define delete_img            _glp_delete_img
-#define get_imgval            _glp_get_imgval
-#define get_pixel             _glp_get_pixel
-#define line_to               _glp_line_to
-#define move_to               _glp_move_to
-#define reset_rgb             _glp_reset_rgb
-#define save_as_bmp           _glp_save_as_bmp
-#define save_as_tiff          _glp_save_as_tiff
-#define save_img              _glp_save_img
-#define set_clipreg           _glp_set_clipreg
-#define set_color             _glp_set_color
-#define set_imgval            _glp_set_imgval
-#define set_logorg            _glp_set_logorg
-#define set_pixel             _glp_set_pixel
-#define set_viewport          _glp_set_viewport
+#define create_img            glp_create_img
+#define delete_img            glp_delete_img
+#define get_imgval            glp_get_imgval
+#define get_pixel             glp_get_pixel
+#define line_to               glp_line_to
+#define move_to               glp_move_to
+#define reset_rgb             glp_reset_rgb
+#define save_as_bmp           glp_save_as_bmp
+#define save_as_tiff          glp_save_as_tiff
+#define save_img              glp_save_img
+#define set_clipreg           glp_set_clipreg
+#define set_color             glp_set_color
+#define set_imgval            glp_set_imgval
+#define set_logorg            glp_set_logorg
+#define set_pixel             glp_set_pixel
+#define set_viewport          glp_set_viewport
 
 typedef struct IMG IMG;
 typedef struct RGB RGB;
