@@ -26,6 +26,8 @@
 #ifndef _GLPK_H
 #define _GLPK_H
 
+#include "glpbcs.h"
+#include "glplib.h"
 #include "glplpx.h"
 
 #endif
