@@ -28,7 +28,6 @@
 
 #include <setjmp.h>
 #include "glpavl.h"
-#include "glplib.h"
 #include "glptext.h"
 
 #define addition              glp_lang_addition
@@ -118,19 +117,19 @@ struct PDB
          valid */
       jmp_buf jump;
       /* jump address for non-local goto in case of error */
-      POOL *spar_pool;
+      DMP *spar_pool;
       /* pool for objects of SPAR type */
-      POOL *item_pool;
+      DMP *item_pool;
       /* pool for objects of ITEM type */
-      POOL *memb_pool;
+      DMP *memb_pool;
       /* pool for objects of MEMB type */
-      POOL *expr_pool;
+      DMP *expr_pool;
       /* pool for objects of EXPR type */
-      POOL *code_pool;
+      DMP *code_pool;
       /* pool for objects of CODE type */
-      POOL *var_pool;
+      DMP *var_pool;
       /* pool for objects of VAR type */
-      POOL *cons_pool;
+      DMP *cons_pool;
       /* pool for objects of CONS type */
       AVLTREE *tree;
       /* symbol table; the type field of the AVLNODE structure defines
@@ -338,7 +337,7 @@ struct prob
       int obj_row;
       /* number of the objective function row (1 to m); zero indicates
          that the objective function is identically equal to zero */
-      POOL *pool;
+      DMP *pool;
       /* memory pool for struct elem instances */
       struct elem **stack; /* struct elem *stack[1+size]; */
       /* stack used for symbolic computation */
@@ -368,7 +367,7 @@ extern void array_decl(int type);
 extern void assign_stmt(void);
 /* parse assignment statement */
 
-extern int cmp_tuples(ITEM *item1[MAX_DIM], ITEM *item2[MAX_DIM]);
+extern int cmp_tuples(void *info, void *key1, void *key2);
 /* compare tuples */
 
 extern struct elem *build_form(struct prob *prob, int i);
