@@ -122,14 +122,19 @@
 #define lpx_transform_col     glp_lpx_transform_col
 #define lpx_prim_ratio_test   glp_lpx_prim_ratio_test
 #define lpx_dual_ratio_test   glp_lpx_dual_ratio_test
+#define lpx_eval_activity     glp_lpx_eval_activity
+#define lpx_eval_red_cost     glp_lpx_eval_red_cost
+#define lpx_reduce_form       glp_lpx_reduce_form
+#define lpx_mixed_gomory      glp_lpx_mixed_gomory
 
-#define lpx_read_lpm          glp_lpx_read_lpm
 #define lpx_read_mps          glp_lpx_read_mps
 #define lpx_write_mps         glp_lpx_write_mps
 #define lpx_print_sol         glp_lpx_print_sol
 #define lpx_print_ips         glp_lpx_print_ips
 #define lpx_print_mip         glp_lpx_print_mip
 
+#define lpx_read_lpm          glp_lpx_read_lpm
+
 /*----------------------------------------------------------------------
 -- The structure LPX defines LP/MIP problem object, which includes the
 -- following information:
@@ -304,7 +309,7 @@ struct LPX
       /* current number of rows (auxiliary variables) */
       int n;
       /* current number of columns (structural variables) */
-      POOL *pool;
+      DMP *pool;
       /* memory pool for segmented character strings */
       char *buf; /* char buf[255+1]; */
       /* working buffer used to return character strings */
@@ -909,10 +914,21 @@ int lpx_dual_ratio_test(LPX *lp, int len, int ndx[], double val[],
       int how, double tol);
 /* perform dual ratio test */
 
-/* additional utility routines ---------------------------------------*/
+double lpx_eval_activity(LPX *lp, int len, int ndx[], double val[]);
+/* compute activity of explicitly specified row */
 
-LPX *lpx_read_lpm(char *infile, char *outfile);
-/* read LP/MIP model written in GLPK/L */
+double lpx_eval_red_cost(LPX *lp, int len, int ndx[], double val[]);
+/* compute red. cost of explicitly specified column */
+
+int lpx_reduce_form(LPX *lp, int len, int ndx[], double val[],
+      double work[]);
+/* reduce linear form */
+
+int lpx_mixed_gomory(LPX *lp, int kind[], int len, int ndx[],
+      double val[], double work[]);
+/* generate Gomory's mixed integer cut */
+
+/* additional utility routines ---------------------------------------*/
 
 LPX *lpx_read_mps(char *fname);
 /* read in problem data using MPS format */
@@ -929,6 +945,9 @@ int lpx_print_ips(LPX *lp, char *fname);
 int lpx_print_mip(LPX *lp, char *fname);
 /* write MIP problem solution in printable format */
 
+LPX *lpx_read_lpm(char *infile, char *outfile);
+/* read LP/MIP model written in GLPK/L */
+
 #endif
 
 /* eof */
