@@ -26,7 +26,7 @@
 #ifndef _GLPMAT_H
 #define _GLPMAT_H
 
-#include "glplib.h"
+#include "glpdmp.h"
 
 #define aat_numb              glp_aat_numb
 #define aat_symb              glp_aat_symb
@@ -83,7 +83,7 @@ typedef struct PER PER;
 
 struct MAT
 {     /* sparse matrix */
-      POOL *pool;
+      DMP *pool;
       /* memory pool for allocating matrix elements */
       int m_max;
       /* current dimension of array of row pointers; this dimension is
