@@ -30,43 +30,43 @@
 #include "glpk.h"
 #include "glplp.h"
 
-#define btran                 _glp_btran
-#define build_basis           _glp_build_basis
-#define change_b              _glp_change_b
-#define check_bbar            _glp_check_bbar
-#define check_cbar            _glp_check_cbar
-#define check_dvec            _glp_check_dvec
-#define check_gvec            _glp_check_gvec
-#define check_rr              _glp_check_rr
-#define check_rsm             _glp_check_rsm
-#define create_rsm            _glp_create_rsm
-#define delete_rsm            _glp_delete_rsm
-#define dual_col              _glp_dual_col
-#define dual_row              _glp_dual_row
-#define eval_bbar             _glp_eval_bbar
-#define eval_cbar             _glp_eval_cbar
-#define eval_col              _glp_eval_col
-#define eval_pi               _glp_eval_pi
-#define eval_row              _glp_eval_row
-#define eval_xn               _glp_eval_xn
-#define eval_zeta             _glp_eval_zeta
-#define exact_dvec            _glp_exact_dvec
-#define exact_gvec            _glp_exact_gvec
-#define ftran                 _glp_ftran
-#define harris_col            _glp_harris_col
-#define harris_row            _glp_harris_row
-#define init_dvec             _glp_init_dvec
-#define init_gvec             _glp_init_gvec
-#define invert_b              _glp_invert_b
-#define pivot_col             _glp_pivot_col
-#define pivot_row             _glp_pivot_row
-#define rsm_dual              _glp_rsm_dual
-#define rsm_feas              _glp_rsm_feas
-#define rsm_primal            _glp_rsm_primal
-#define scale_rsm             _glp_scale_rsm
-#define update_b              _glp_update_b
-#define update_dvec           _glp_update_dvec
-#define update_gvec           _glp_update_gvec
+#define btran                 glp_btran
+#define build_basis           glp_build_basis
+#define change_b              glp_change_b
+#define check_bbar            glp_check_bbar
+#define check_cbar            glp_check_cbar
+#define check_dvec            glp_check_dvec
+#define check_gvec            glp_check_gvec
+#define check_rr              glp_check_rr
+#define check_rsm             glp_check_rsm
+#define create_rsm            glp_create_rsm
+#define delete_rsm            glp_delete_rsm
+#define dual_col              glp_dual_col
+#define dual_row              glp_dual_row
+#define eval_bbar             glp_eval_bbar
+#define eval_cbar             glp_eval_cbar
+#define eval_col              glp_eval_col
+#define eval_pi               glp_eval_pi
+#define eval_row              glp_eval_row
+#define eval_xn               glp_eval_xn
+#define eval_zeta             glp_eval_zeta
+#define exact_dvec            glp_exact_dvec
+#define exact_gvec            glp_exact_gvec
+#define ftran                 glp_ftran
+#define harris_col            glp_harris_col
+#define harris_row            glp_harris_row
+#define init_dvec             glp_init_dvec
+#define init_gvec             glp_init_gvec
+#define invert_b              glp_invert_b
+#define pivot_col             glp_pivot_col
+#define pivot_row             glp_pivot_row
+#define rsm_dual              glp_rsm_dual
+#define rsm_feas              glp_rsm_feas
+#define rsm_primal            glp_rsm_primal
+#define scale_rsm             glp_scale_rsm
+#define update_b              glp_update_b
+#define update_dvec           glp_update_dvec
+#define update_gvec           glp_update_gvec
 
 typedef struct RSM RSM;
 
@@ -252,8 +252,10 @@ extern int rsm_feas(RSM *rsm, int (*monit)(void),
 
 /*** auxiliary routines ***/
 
+#if 0
 extern RSM *create_rsm(LPI *lp);
 /* create revised simplex method common block */
+#endif
 
 extern void delete_rsm(RSM *rsm);
 /* delete revised simplex method common block */
@@ -261,8 +263,10 @@ extern void delete_rsm(RSM *rsm);
 extern void scale_rsm(RSM *rsm, double R[], double S[]);
 /* scale problem components in RSM block */
 
+#if 0
 extern int build_basis(RSM *rsm, LPI *lp);
 /* build advanced basis */
+#endif
 
 #endif
 
