@@ -26,7 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include "glpk.h"
-#include "glplib.h"
 
 /*----------------------------------------------------------------------
 -- This program is a stand-alone LP/MIP solver. For pure LP problems
@@ -416,11 +415,9 @@ int main(int argc, char *argv[])
       }
 skip: /* delete the problem object */
       lpx_delete_prob(lp);
-#if 0
-      print("%d %d",
-         lib_env_ptr()->mem_total, lib_env_ptr()->mem_count);
-#endif
-      /* exit to the control program */
+      insist(lib_env_ptr()->mem_total == 0);
+      insist(lib_env_ptr()->mem_count == 0);
+      /* return to the control program */
       return 0;
 }
 
