@@ -27,6 +27,7 @@
 #include <math.h>
 #include <stddef.h>
 #include "glpbbm.h"
+#include "glplib.h"
 
 /*----------------------------------------------------------------------
 -- bbm1_driver - driver for the branch-and-bound method.
@@ -182,8 +183,8 @@ static void initialize(LP *mip, LPSOL *sol)
       bb->tagx = ucalloc(1+m+n, sizeof(int));
       for (k = 1; k <= m+n; k++) bb->tagx[k] = sol->tagx[k];
       /* create empty branch-and-bound tree */
-      bb->node_pool = create_pool(sizeof(BBNODE));
-      bb->tagx_pool = create_pool(sizeof(BBTAGX));
+      bb->node_pool = dmp_create_pool(sizeof(BBNODE));
+      bb->tagx_pool = dmp_create_pool(sizeof(BBTAGX));
       bb->root = bb->first = bb->last = NULL;
       bb->count = bb->total = 0;
       bb->found = 0;
@@ -249,7 +250,7 @@ static void initialize(LP *mip, LPSOL *sol)
       start = utime();
       t_last = -1.0;
       /* create the root problem */
-      node = get_atom(bb->node_pool);
+      node = dmp_get_atom(bb->node_pool);
       node->up = NULL;
       node->j = 0;
       node->type = '?';
@@ -1095,7 +1096,7 @@ static void save_diff(BBNODE *node)
          {  /* the variable x[k] has different status; add a new entry
                to the list of differences */
             BBTAGX *t;
-            t = get_atom(bb->tagx_pool);
+            t = dmp_get_atom(bb->tagx_pool);
             t->k = k;
             t->tagx = temp;
             t->next = node->diff;
@@ -1190,7 +1191,7 @@ static void split_node(BBNODE *node, int j)
          basis solution of the current problem */
       beta = get_value(m+j);
       /* create the first child subproblem */
-      child = node->left = get_atom(bb->node_pool);
+      child = node->left = dmp_get_atom(bb->node_pool);
       child->up = node;
       child->j = j;
       child->type = 'L';
@@ -1209,7 +1210,7 @@ static void split_node(BBNODE *node, int j)
       bb->last = child;
       bb->count++;
       /* create the second child subproblem */
-      child = node->right = get_atom(bb->node_pool);
+      child = node->right = dmp_get_atom(bb->node_pool);
       child->up = node;
       child->j = j;
       child->type = 'U';
@@ -1254,11 +1255,11 @@ loop: /* determine the parent */
       /* free the list of differences */
       while (node->diff != NULL)
       {  BBTAGX *t = node->diff->next;
-         free_atom(bb->tagx_pool, node->diff);
+         dmp_free_atom(bb->tagx_pool, node->diff);
          node->diff = t;
       }
       /* delete the current node */
-      free_atom(bb->node_pool, node);
+      dmp_free_atom(bb->node_pool, node);
       /* if the parent exists and now has no childs, it also should be
          removed from the tree */
       if (parent != NULL)
@@ -1346,8 +1347,8 @@ static BBNODE *select_node(void)
 static void terminate(void)
 {     delete_lp(bb->mip);
       ufree(bb->tagx);
-      delete_pool(bb->node_pool);
-      delete_pool(bb->tagx_pool);
+      dmp_delete_pool(bb->node_pool);
+      dmp_delete_pool(bb->tagx_pool);
       ufree(bb->rsm->type);
       ufree(bb->rsm->lb);
       ufree(bb->rsm->ub);
