@@ -30,8 +30,6 @@
 #include "glpimg.h"
 #include "glplib.h"
 
-#define error print
-
 /*----------------------------------------------------------------------
 -- create_img - create raster image.
 --
@@ -513,7 +511,7 @@ int save_as_bmp(IMG *img, char *fname)
       int offset, bmsize, bitcnt;
       fp = fopen(fname, "wb");
       if (fp == NULL)
-      {  error("save_as_bmp: can't create `%s' - %s", fname,
+      {  print("save_as_bmp: can't create `%s' - %s", fname,
             strerror(errno));
          goto fail;
       }
@@ -644,7 +642,7 @@ int save_as_bmp(IMG *img, char *fname)
       }
       fflush(fp);
       if (ferror(fp))
-      {  error("save_as_bmp: can't write to `%s' - %s", fname,
+      {  print("save_as_bmp: can't write to `%s' - %s", fname,
             strerror(errno));
          goto fail;
       }
@@ -702,7 +700,7 @@ int save_as_tiff(IMG *img, char *fname)
       int loc_0111, loc_0140, loc_011A, loc_011B, k, x, y, temp;
       fp = fopen(fname, "wb");
       if (fp == NULL)
-      {  error("save_as_tiff: can't create `%s' - %s", fname,
+      {  print("save_as_tiff: can't create `%s' - %s", fname,
             strerror(errno));
          goto fail;
       }
@@ -960,7 +958,7 @@ int save_as_tiff(IMG *img, char *fname)
       }
       fflush(fp);
       if (ferror(fp))
-      {  error("save_as_tiff: can't write to `%s' - %s", fname,
+      {  print("save_as_tiff: can't write to `%s' - %s", fname,
             strerror(errno));
          goto fail;
       }
