@@ -27,6 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "glplang.h"
+#include "glplib.h"
 #include "glpmat.h"
 
 /*----------------------------------------------------------------------
@@ -122,8 +123,8 @@ struct prob *create_prob(void)
          numbers to rows, and determine required stack size */
       m = 0;
       size = 0;
-      for (node = next_node(pdb->tree, NULL); node != NULL;
-           node = next_node(pdb->tree, node))
+      for (node = avl_find_next_node(pdb->tree, NULL); node != NULL;
+           node = avl_find_next_node(pdb->tree, node))
       {  if (node->type == 'C')
          {  spar = node->link;
             for (memb = spar->first; memb != NULL; memb = memb->next)
@@ -138,8 +139,8 @@ struct prob *create_prob(void)
       /* determine number of columns (variables) and assign sequential
          numbers to columns */
       n = 0;
-      for (node = next_node(pdb->tree, NULL); node != NULL;
-           node = next_node(pdb->tree, node))
+      for (node = avl_find_next_node(pdb->tree, NULL); node != NULL;
+           node = avl_find_next_node(pdb->tree, node))
       {  if (node->type == 'V')
          {  spar = node->link;
             for (memb = spar->first; memb != NULL; memb = memb->next)
@@ -160,14 +161,14 @@ struct prob *create_prob(void)
          prob->obj_row = 0;
       else
          prob->obj_row = ((CONS *)pdb->obj_memb->link)->seqn;
-      prob->pool = create_pool(sizeof(struct elem));
+      prob->pool = dmp_create_pool(sizeof(struct elem));
       prob->stack = ucalloc(1+size, sizeof(struct elem *));
       prob->work = ucalloc(1+n, sizeof(double));
       for (j = 0; j <= n; j++) prob->work[j] = 0.0;
       /* build row (constraint) list */
       k = 0;
-      for (node = next_node(pdb->tree, NULL); node != NULL;
-           node = next_node(pdb->tree, node))
+      for (node = avl_find_next_node(pdb->tree, NULL); node != NULL;
+           node = avl_find_next_node(pdb->tree, node))
       {  if (node->type == 'C')
          {  spar = node->link;
             for (memb = spar->first; memb != NULL; memb = memb->next)
@@ -178,8 +179,8 @@ struct prob *create_prob(void)
          }
       }
       /* build column (variable) list */
-      for (node = next_node(pdb->tree, NULL); node != NULL;
-           node = next_node(pdb->tree, node))
+      for (node = avl_find_next_node(pdb->tree, NULL); node != NULL;
+           node = avl_find_next_node(pdb->tree, node))
       {  if (node->type == 'V')
          {  spar = node->link;
             for (memb = spar->first; memb != NULL; memb = memb->next)
@@ -204,7 +205,7 @@ void erase_form(struct prob *prob, struct elem *row)
       while (row != NULL)
       {  e = row;
          row = e->next;
-         free_atom(prob->pool, e);
+         dmp_free_atom(prob->pool, e);
       }
       return;
 }
@@ -232,7 +233,7 @@ struct elem *build_form(struct prob *prob, int i)
       {  switch (code->op)
          {  case C_CON:
                /* model constant */
-               e = get_atom(prob->pool);
+               e = dmp_get_atom(prob->pool);
                e->j = 0;
                e->val = code->arg.con;
                e->next = NULL;
@@ -240,7 +241,7 @@ struct elem *build_form(struct prob *prob, int i)
                break;
             case C_VAR:
                /* model variable */
-               e = get_atom(prob->pool);
+               e = dmp_get_atom(prob->pool);
                e->j = ((VAR *)code->arg.var.memb->link)->seqn;
                insist(0 <= e->j && e->j <= n);
                e->val = 1.0;
@@ -273,7 +274,7 @@ struct elem *build_form(struct prob *prob, int i)
                /* add new non-zero elements to x */
                for (e = y; e != NULL; e = e->next)
                {  if (work[e->j] != 0.0)
-                  {  struct elem *ee = get_atom(prob->pool);
+                  {  struct elem *ee = dmp_get_atom(prob->pool);
                      ee->j = e->j;
                      ee->val = work[e->j], work[e->j] = 0.0;
                      ee->next = x, x = ee;
@@ -340,7 +341,7 @@ err:           {  /* both multiplicands are linear form */
 void delete_prob(struct prob *prob)
 {     ufree(prob->spar);
       ufree(prob->memb);
-      delete_pool(prob->pool);
+      dmp_delete_pool(prob->pool);
       ufree(prob->stack);
       ufree(prob->work);
       ufree(prob);
