@@ -27,6 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "glplang.h"
+#include "glplib.h"
 
 /*----------------------------------------------------------------------
 -- initialize - initialize the language processor environment.
@@ -50,14 +51,14 @@ int initialize(char *fname)
          return 1;
       }
       pdb->flag = 0;
-      pdb->spar_pool = create_pool(sizeof(SPAR));
-      pdb->item_pool = create_pool(sizeof(ITEM));
-      pdb->memb_pool = create_pool(sizeof(MEMB));
-      pdb->expr_pool = create_pool(sizeof(EXPR));
-      pdb->code_pool = create_pool(sizeof(CODE));
-      pdb->var_pool = create_pool(sizeof(VAR));
-      pdb->cons_pool = create_pool(sizeof(CONS));
-      pdb->tree = create_avl((int (*)(void *, void *))strcmp);
+      pdb->spar_pool = dmp_create_pool(sizeof(SPAR));
+      pdb->item_pool = dmp_create_pool(sizeof(ITEM));
+      pdb->memb_pool = dmp_create_pool(sizeof(MEMB));
+      pdb->expr_pool = dmp_create_pool(sizeof(EXPR));
+      pdb->code_pool = dmp_create_pool(sizeof(CODE));
+      pdb->var_pool = dmp_create_pool(sizeof(VAR));
+      pdb->cons_pool = dmp_create_pool(sizeof(CONS));
+      pdb->tree = avl_create_tree(NULL, avl_strcmp);
       strcpy(pdb->model_name, "unknown");
       pdb->obj_dir = '-';
       pdb->obj_spar = NULL;
@@ -76,15 +77,15 @@ int initialize(char *fname)
 void terminate(void)
 {     insist(pdb != NULL);
       close_text(pdb->text);
-      delete_pool(pdb->spar_pool);
-      delete_pool(pdb->item_pool);
-      delete_pool(pdb->memb_pool);
-      delete_pool(pdb->expr_pool);
-      delete_pool(pdb->code_pool);
-      delete_pool(pdb->var_pool);
-      delete_pool(pdb->cons_pool);
-      delete_avl(pdb->tree);
-      if (pdb->index != NULL) delete_avl(pdb->index);
+      dmp_delete_pool(pdb->spar_pool);
+      dmp_delete_pool(pdb->item_pool);
+      dmp_delete_pool(pdb->memb_pool);
+      dmp_delete_pool(pdb->expr_pool);
+      dmp_delete_pool(pdb->code_pool);
+      dmp_delete_pool(pdb->var_pool);
+      dmp_delete_pool(pdb->cons_pool);
+      avl_delete_tree(pdb->tree);
+      if (pdb->index != NULL) avl_delete_tree(pdb->index);
       ufree(pdb);
       pdb = NULL;
       return;
@@ -176,7 +177,7 @@ int find_mute(int dim, int mute[], int i)
 
 void create_index(SPAR *spar)
 {     insist(pdb->index == NULL);
-      pdb->index = create_avl((int (*)(void *, void *))cmp_tuples);
+      pdb->index = avl_create_tree(NULL, cmp_tuples);
       pdb->array = spar;
       return;
 }
@@ -187,8 +188,11 @@ void create_index(SPAR *spar)
 -- This routine is auxiliary. It is used by array indexing routines for
 -- comparing two tuples. */
 
-int cmp_tuples(ITEM *item1[MAX_DIM], ITEM *item2[MAX_DIM])
-{     int k;
+int cmp_tuples(void *info, void *key1, void *key2)
+{     ITEM **item1 = key1; /* ITEM *item1[MAX_DIM]; */
+      ITEM **item2 = key2; /* ITEM *item2[MAX_DIM]; */
+      int k;
+      insist(info == info);
       for (k = 0; k < pdb->array->dim; k++)
       {  if (item1[k] < item2[k]) return -1;
          if (item1[k] > item2[k]) return +1;
@@ -208,7 +212,7 @@ int cmp_tuples(ITEM *item1[MAX_DIM], ITEM *item2[MAX_DIM])
 MEMB *find_memb(ITEM *item[MAX_DIM])
 {     AVLNODE *node;
       insist(pdb->index != NULL);
-      node = find_by_key(pdb->index, item);
+      node = avl_find_by_key(pdb->index, item);
       return node == NULL ? NULL : (MEMB *)node->link;
 }
 
@@ -222,7 +226,7 @@ MEMB *find_memb(ITEM *item[MAX_DIM])
 void index_memb(MEMB *memb)
 {     AVLNODE *node;
       insist(pdb->index != NULL);
-      node = insert_by_key(pdb->index, memb->item);
+      node = avl_insert_by_key(pdb->index, memb->item);
       node->link = memb;
       return;
 }
@@ -235,7 +239,7 @@ void index_memb(MEMB *memb)
 
 void delete_index(void)
 {     insist(pdb->index != NULL);
-      delete_avl(pdb->index);
+      avl_delete_tree(pdb->index);
       pdb->index = NULL;
       pdb->array = NULL;
       return;
