@@ -26,6 +26,7 @@
 #include <ctype.h>
 #include <string.h>
 #include "glplang.h"
+#include "glplib.h"
 
 /*----------------------------------------------------------------------
 -- constant - parse constant literal.
@@ -44,7 +45,7 @@
 SPAR *constant(void)
 {     SPAR *spar;
       MEMB *memb;
-      spar = get_atom(pdb->spar_pool);
+      spar = dmp_get_atom(pdb->spar_pool);
       if (t_name("false"))
       {  /* scalar predicate (assertion) *false* */
          strcpy(spar->name, "<false>");
@@ -57,7 +58,7 @@ SPAR *constant(void)
          strcpy(spar->name, "<true>");
          spar->type = 'P';
          spar->dim = 0;
-         spar->first = spar->last = memb = get_atom(pdb->memb_pool);
+         spar->first = spar->last = memb = dmp_get_atom(pdb->memb_pool);
          memb->link = NULL;
          memb->next = NULL;
       }
@@ -73,7 +74,7 @@ SPAR *constant(void)
          strcpy(spar->name, "<const>");
          spar->type = 'X';
          spar->dim = 0;
-         spar->first = spar->last = memb = get_atom(pdb->memb_pool);
+         spar->first = spar->last = memb = dmp_get_atom(pdb->memb_pool);
          memb->link = make_const(pdb->text->t_real);
          memb->next = NULL;
       }
@@ -125,7 +126,7 @@ SPAR *designator(char *name)
       MEMB *memb;
       int k, t;
       /* determine original array */
-      node = find_by_key(pdb->tree, name);
+      node = avl_find_by_key(pdb->tree, name);
       if (node == NULL)
          fatal("`%s' not declared", name);
       if (node->type == 'I')
@@ -197,7 +198,7 @@ SPAR *designator(char *name)
             get_token(/* # */);
             if (token != T_NAME)
                fatal("item name missing or invalid");
-            node = find_by_key(pdb->tree, image);
+            node = avl_find_by_key(pdb->tree, image);
             if (node == NULL)
                fatal("item `%s' not declared", image);
             if (node->type != 'I')
@@ -221,7 +222,7 @@ SPAR *designator(char *name)
          fatal("too few subscripts for `%s'", orig->name);
       get_token(/* ] */);
 skip: /* create resultant array */
-      spar = get_atom(pdb->spar_pool);
+      spar = dmp_get_atom(pdb->spar_pool);
       strcpy(spar->name, orig->name);
       switch (orig->type)
       {  case 'S': spar->type = 'P'; break;
@@ -326,7 +327,7 @@ skip: /* create resultant array */
             if (t >= 0 && item[t] != item[k]) goto miss;
          }
          /* create resultant element and build its tuple */
-         temp = get_atom(pdb->memb_pool);
+         temp = dmp_get_atom(pdb->memb_pool);
          for (k = 0; k < orig->dim; k++)
          {  if (form[k] == 0 || form[k] == 1)
             {  t = find_mute(spar->dim, spar->mute, mute[k]);
@@ -423,7 +424,7 @@ SPAR *data_func(void)
       insist(t_spec("("));
       get_token(/* ( */);
       /* create array */
-      spar = get_atom(pdb->spar_pool);
+      spar = dmp_get_atom(pdb->spar_pool);
       strcpy(spar->name, "<data>");
       spar->type = 'X';
       spar->dim = 0;
@@ -446,7 +447,7 @@ SPAR *data_func(void)
          get_token(/* in */);
          if (token != T_NAME)
             fatal("set name missing or invalid");
-         node = find_by_key(pdb->tree, image);
+         node = avl_find_by_key(pdb->tree, image);
          if (node == NULL)
             fatal("set `%s' not declared", image);
          if (node->type != 'S')
@@ -473,7 +474,7 @@ SPAR *data_func(void)
             else
             {  if (token != T_NAME)
                   fatal("item name missing or invalid");
-               node = find_by_key(pdb->tree, image);
+               node = avl_find_by_key(pdb->tree, image);
                if (node == NULL)
                   fatal("item `%s' not declared", image);
                if (node->type != 'I')
@@ -507,7 +508,7 @@ SPAR *data_func(void)
             spar->last = memb;
             index_memb(memb);
          }
-         free_atom(pdb->spar_pool, temp);
+         dmp_free_atom(pdb->spar_pool, temp);
          /* check delimiter */
          if (t_spec(")")) break;
          if (t_spec(",")) get_token(/* , */);
@@ -601,7 +602,7 @@ SPAR *table_func(void)
       insist(t_spec("("));
       get_token(/* ( */);
       /* create resultant 2-d array */
-      spar = get_atom(pdb->spar_pool);
+      spar = dmp_get_atom(pdb->spar_pool);
       strcpy(spar->name, "<table>");
       spar->type = 'X';
       spar->dim = 2;
@@ -621,7 +622,7 @@ SPAR *table_func(void)
          get_token(/* in */);
          if (token != T_NAME)
             fatal("set name missing or invalid");
-         node = find_by_key(pdb->tree, image);
+         node = avl_find_by_key(pdb->tree, image);
          if (node == NULL)
             fatal("set `%s' not declared", image);
          if (node->type != 'S')
@@ -644,7 +645,7 @@ SPAR *table_func(void)
             fatal("too many columns");
          if (token != T_NAME)
             fatal("column name missing or invalid");
-         node = find_by_key(pdb->tree, image);
+         node = avl_find_by_key(pdb->tree, image);
          if (node == NULL)
             fatal("item `%s' not declared", image);
          if (node->type != 'I')
@@ -662,7 +663,7 @@ SPAR *table_func(void)
       for (;;)
       {  if (token != T_NAME)
             fatal("row name missing or invalid");
-         node = find_by_key(pdb->tree, image);
+         node = avl_find_by_key(pdb->tree, image);
          if (node == NULL)
             fatal("item `%s' not declared", image);
          if (node->type != 'I')
@@ -701,7 +702,7 @@ SPAR *table_func(void)
                   spar->last = memb;
                   index_memb(memb);
                }
-               free_atom(pdb->spar_pool, temp);
+               dmp_free_atom(pdb->spar_pool, temp);
             }
             if (k < n && t_spec(",")) get_token(/* , */);
          }
