@@ -25,6 +25,7 @@
 
 #include <string.h>
 #include "glplang.h"
+#include "glplib.h"
 
 /*----------------------------------------------------------------------
 -- erase_spar - delete sparse array.
@@ -39,9 +40,9 @@ void erase_spar(SPAR *spar)
       {  memb = spar->first;
          spar->first = memb->next;
          if (spar->type == 'X') erase_expr(memb->link);
-         free_atom(pdb->memb_pool, memb);
+         dmp_free_atom(pdb->memb_pool, memb);
       }
-      free_atom(pdb->spar_pool, spar);
+      dmp_free_atom(pdb->spar_pool, spar);
       return;
 }
 
@@ -64,7 +65,7 @@ SPAR *expand_spar(SPAR *x, SPAR *set, int i)
       insist(x->dim < MAX_DIM);
       insist(set->type == 'S');
       /* create the resultant array of higher dimension */
-      y = get_atom(pdb->spar_pool);
+      y = dmp_get_atom(pdb->spar_pool);
       memcpy(y, x, sizeof(SPAR));
       y->set[y->dim] = set;
       y->mute[y->dim] = i;
@@ -75,7 +76,7 @@ SPAR *expand_spar(SPAR *x, SPAR *set, int i)
       for (memx = x->first; memx != NULL; memx = memx->next)
       {  for (memb = set->first; memb != NULL; memb = memb->next)
          {  /* create and add new element to the resultant array */
-            memy = get_atom(pdb->memb_pool);
+            memy = dmp_get_atom(pdb->memb_pool);
             memcpy(memy, memx, sizeof(MEMB));
             memy->item[y->dim-1] = memb->item[0];
             if (y->type == 'P')
@@ -231,10 +232,10 @@ SPAR *addition(int op, SPAR *x, SPAR *y)
          else
          {  /* member already exists */
             temp->link = make_expr(op, temp->link, memb->link);
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
          }
       }
-      free_atom(pdb->spar_pool, y);
+      dmp_free_atom(pdb->spar_pool, y);
       delete_index();
       return x;
 }
@@ -254,7 +255,7 @@ SPAR *multiplication(int op, SPAR *x, SPAR *y)
       if (!(x->type == 'X' && y->type == 'X'))
          fatal("invalid operand of binary arithmetic operation");
       /* create resultant array; determine its dimension and domains */
-      z = get_atom(pdb->spar_pool);
+      z = dmp_get_atom(pdb->spar_pool);
       switch (op)
       {  case C_MUL:
             strcpy(z->name, "<multiplication>");
@@ -311,7 +312,7 @@ SPAR *multiplication(int op, SPAR *x, SPAR *y)
             }
             /* if both operands have no multiplets, there will be no
                multiplets in the resultant array */
-            memb = get_atom(pdb->memb_pool);
+            memb = dmp_get_atom(pdb->memb_pool);
             for (k = 0; k < z->dim; k++) memb->item[k] = item[k];
             memb->link = make_expr(op,
                copy_expr(memx->link), copy_expr(memy->link));
@@ -369,7 +370,7 @@ SPAR *selection(SPAR *x, SPAR *y)
          }
          if (find_memb(item) == NULL)
          {  erase_expr(memb->link);
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
          }
          else
          {  memb->next = NULL;
@@ -451,7 +452,7 @@ err:     fatal("invalid operand of relation operation");
          memb->link = NULL;
          memb->next = NULL;
          if (cond == 0.0)
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
          else
          {  if (x->first == NULL)
                x->first = memb;
@@ -478,7 +479,7 @@ SPAR *logical_not(SPAR *x)
       if (x->type != 'P')
          fatal("invalid operand of unary logical operation");
       /* create resultant predicate */
-      z = get_atom(pdb->spar_pool);
+      z = dmp_get_atom(pdb->spar_pool);
       memcpy(z, x, sizeof(SPAR));
       strcpy(z->name, "<logical not>");
       z->first = z->last = NULL;
@@ -506,7 +507,7 @@ SPAR *logical_not(SPAR *x)
          /* if the corresponding element is not in the predicate x,
             include it in the resultant predicate */
          if (find_memb(item) == NULL)
-         {  memb = get_atom(pdb->memb_pool);
+         {  memb = dmp_get_atom(pdb->memb_pool);
             for (t = 0; t < x->dim; t++)
                memb->item[t] = item[t];
             memb->link = NULL;
@@ -541,7 +542,7 @@ SPAR *logical_and(SPAR *x, SPAR *y)
          fatal("invalid operand of binary logical operation");
       /* create resultant predicate; determine its dimension and domain
          sets */
-      z = get_atom(pdb->spar_pool);
+      z = dmp_get_atom(pdb->spar_pool);
       strcpy(z->name, "<logical and>");
       z->type = 'P';
       z->dim = x->dim;
@@ -589,7 +590,7 @@ SPAR *logical_and(SPAR *x, SPAR *y)
             }
             /* if both operands have no multiplets, there will be no
                multiplets in the resultant predicate */
-            memb = get_atom(pdb->memb_pool);
+            memb = dmp_get_atom(pdb->memb_pool);
             for (k = 0; k < z->dim; k++) memb->item[k] = item[k];
             memb->link = NULL;
             memb->next = NULL;
@@ -678,10 +679,10 @@ SPAR *logical_or(SPAR *x, SPAR *y)
          }
          else
          {  /* member already exists */
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
          }
       }
-      free_atom(pdb->spar_pool, y);
+      dmp_free_atom(pdb->spar_pool, y);
       delete_index();
       return x;
 }
@@ -708,7 +709,7 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
             fatal("mute letter `%c' missing in array operand", mute[k]);
       }
       /* create resultant array; determine its dimension and domains */
-      z = get_atom(pdb->spar_pool);
+      z = dmp_get_atom(pdb->spar_pool);
       strcpy(z->name, "<sum>");
       z->type = 'X';
       z->dim = 0;
@@ -749,11 +750,11 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
          else
          {  /* member already exists */
             temp->link = make_expr(C_ADD, temp->link, memb->link);
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
          }
       }
       delete_index();
-      free_atom(pdb->spar_pool, x);
+      dmp_free_atom(pdb->spar_pool, x);
       return z;
 }
 
