@@ -27,6 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "glplang.h"
+#include "glplib.h"
 
 /*----------------------------------------------------------------------
 -- assign_stmt - parse assignment statement.
@@ -69,7 +70,7 @@ void assign_stmt(void)
       int k, t;
       /* determine array in the left part */
       insist(token == T_NAME);
-      node = find_by_key(pdb->tree, image);
+      node = avl_find_by_key(pdb->tree, image);
       if (node == NULL)
          fatal("`%s' not declared", image);
       if (node->type == 'I')
@@ -129,7 +130,7 @@ void assign_stmt(void)
             get_token(/* # */);
             if (token != T_NAME)
                fatal("item name missing or invalid");
-            node = find_by_key(pdb->tree, image);
+            node = avl_find_by_key(pdb->tree, image);
             if (node == NULL)
                fatal("item `%s' not declared", image);
             if (node->type != 'I')
@@ -258,21 +259,21 @@ skip: /* parse optional predicate */
          /* destroy the current member */
          if (spar->type == 'P')
          {  insist(memb->link == NULL);
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
             continue;
          }
          if (spar->type == 'X')
          {  insist(memb->link != NULL);
             erase_expr(memb->link);
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->memb_pool, memb);
             continue;
          }
          if (spar->type == 'C' && suff == 0)
          {  CONS *cons = memb->link;
             insist(cons != NULL && cons->expr != NULL);
             erase_expr(cons->expr);
-            free_atom(pdb->cons_pool, cons);
-            free_atom(pdb->memb_pool, memb);
+            dmp_free_atom(pdb->cons_pool, cons);
+            dmp_free_atom(pdb->memb_pool, memb);
             continue;
          }
          /* pseudo arrays */
@@ -345,7 +346,7 @@ keep:    /* keep the current member */
                {  insist(memb->link != NULL);
                   erase_expr(memb->link);
                }
-               free_atom(pdb->memb_pool, memb);
+               dmp_free_atom(pdb->memb_pool, memb);
             }
             else
             {  /* predicate is *true* */
@@ -396,7 +397,7 @@ keep:    /* keep the current member */
          }
          if (spar->type == 'C' && suff == 0)
          {  CONS *cons;
-            cons = get_atom(pdb->cons_pool);
+            cons = dmp_get_atom(pdb->cons_pool);
             insist(memb->link != NULL);
             cons->expr = memb->link;
             switch (form)
@@ -477,7 +478,7 @@ keep:    /* keep the current member */
          }
          /* destroy right part member */
          erase_expr(memb->link);
-         free_atom(pdb->memb_pool, memb);
+         dmp_free_atom(pdb->memb_pool, memb);
          continue;
 add:     /* add right part member to the left part array */
          /* there should be NO multiplets */
@@ -490,7 +491,7 @@ add:     /* add right part member to the left part array */
          spar->last = memb;
       }
       delete_index();
-      free_atom(pdb->spar_pool, that);
+      dmp_free_atom(pdb->spar_pool, that);
       /* check delimiter */
       if (!t_spec(";")) fatal("semicolon expected");
       get_token(/* ; */);
@@ -524,7 +525,7 @@ void objective(void)
       /* parse constraint name */
       if (token != T_NAME)
          fatal("objective name missing or invalid");
-      node = find_by_key(pdb->tree, image);
+      node = avl_find_by_key(pdb->tree, image);
       if (node == NULL)
          fatal("objective `%s' not declared", image);
       if (node->type != 'C')
@@ -550,7 +551,7 @@ void objective(void)
          get_token(/* # */);
          if (token != T_NAME)
             fatal("item name missing or invalid");
-         node = find_by_key(pdb->tree, image);
+         node = avl_find_by_key(pdb->tree, image);
          if (node == NULL)
             fatal("item `%s' not declared", image);
          if (node->type != 'I')
@@ -604,7 +605,7 @@ void display_stmt(void)
       outstr("\n");
       get_token(/* print */);
 loop: if (token == T_NAME)
-      {  node = find_by_key(pdb->tree, image);
+      {  node = avl_find_by_key(pdb->tree, image);
          if (node == NULL)
             fatal("symbol `%s' not declared", image);
          if (node->type == 'I')
