@@ -26,6 +26,7 @@
 #include <ctype.h>
 #include <math.h>
 #include <string.h>
+#include "glplib.h"
 #include "glplpx.h"
 
 /*----------------------------------------------------------------------
@@ -1335,7 +1336,7 @@ void lpx_del_items(LPX *lp)
 -- parameter lp points to, freeing all the memory allocated to it. */
 
 void lpx_delete_prob(LPX *lp)
-{     delete_pool(lp->pool);
+{     dmp_delete_pool(lp->pool);
       ufree(lp->buf);
       ufree(lp->name);
       ufree(lp->typx);
