@@ -24,6 +24,9 @@
 ----------------------------------------------------------------------*/
 
 #include <float.h>
+#include <math.h>
+#include <stddef.h>
+#include "glplib.h"
 #include "glpspx.h"
 
 /*----------------------------------------------------------------------
@@ -838,4 +841,542 @@ int lpx_dual_ratio_test(LPX *lp, int len, int ndx[], double val[],
       return q;
 }
 
+/*----------------------------------------------------------------------
+-- lpx_eval_activity - compute activity of explicitly specified row.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- double lpx_eval_activity(LPX *lp, int len, int ndx[], double val[]);
+--
+-- *Description*
+--
+-- The routine lpx_eval_activity computes activity (primal value) of the
+-- explicitly specified row as if this row were presented in the problem
+-- object and the corresponding auxiliary variable were basic.
+--
+-- The explicitly specified row may be thought as a linear form
+--
+--    x = a[1]*x[m+1] + a[2]*x[m+2] + ... + a[n]*x[m+n],             (*)
+--
+-- where x is an auxiliary variable for this row, a[j] are coefficients
+-- of the linear form, x[m+j] are structural variables.
+--
+-- Column indices and numerical values of non-zero elements of the row
+-- should be placed in locations ndx[1], ..., ndx[len] and val[1], ...,
+-- val[len], respectively, where len is number of non-zero elements. The
+-- arrays ndx and val are not changed by the routine.
+--
+-- *Returns*
+--
+-- The routine lpx_eval_activity returns activity (primal value) of the
+-- explicitly specified row.
+--
+-- *Algorithm*
+--
+-- Activity of the row (*), which is a value of the auxiliary variable
+-- x, is computed by substituting values of structural variables for the
+-- current basic solution. */
+
+double lpx_eval_activity(LPX *lp, int len, int ndx[], double val[])
+{     int n = lp->n;
+      int j, t;
+      double sum, vx;
+      /* check the explicitly specified row */
+      if (!(0 <= len && len <= n))
+         fault("lpx_eval_activity: len = %d; invalid row length", len);
+      for (t = 1; t <= len; t++)
+      {  j = ndx[t];
+         if (!(1 <= j && j <= n))
+            fault("lpx_eval_activity: ndx[%d] = %d; column number out o"
+               "f range", t, j);
+      }
+      /* the current primal basic solution should exist */
+      if (lp->p_stat == LPX_P_UNDEF)
+         fault("lpx_eval_activity: current primal basic solution not ex"
+            "ist");
+      /* substitute the current values of structural variable into the
+         linear form */
+      sum = 0.0;
+      for (t = 1; t <= len; t++)
+      {  if (val[t] != 0.0)
+         {  j = ndx[t];
+            lpx_get_col_info(lp, j, NULL, &vx, NULL);
+            sum += val[t] * vx;
+         }
+      }
+      return sum;
+}
+
+/*----------------------------------------------------------------------
+-- lpx_eval_red_cost - compute red. cost of explicitly specified column.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- double lpx_eval_red_cost(LPX *lp, int len, int ndx[], double val[]);
+--
+-- *Description*
+--
+-- The routine lpx_eval_red_cost computes reduced cost (dual value) of
+-- the explicitly specified column as if this column were presented in
+-- the problem object and the corresponding structural variable were
+-- non-basic.
+--
+-- The explicitly specified column may be thought as it were added to
+-- the original system of equality constraints:
+--
+--    x[1] = a[1,1]*x[m+1] + ... + a[1,n]*x[m+n] + a[1]*x
+--    x[2] = a[2,1]*x[m+1] + ... + a[2,n]*x[m+n] + a[2]*x            (*)
+--       .  .  .  .  .  .  .  .  .  .  .  .  .  .  .
+--    x[m] = a[m,1]*x[m+1] + ... + a[m,n]*x[m+n] + a[m]*x
+--
+-- where x[i] are auxiliary variables, x[m+j] are structural variables,
+-- x is a structural variable for the explicitly specified column, a[i]
+-- are constraint coefficients for x.
+--
+-- Row indices and numerical values of non-zero elements of the column
+-- should be placed in locations ndx[1], ..., ndx[len] and val[1], ...,
+-- val[len], respectively, where len is number of non-zero elements. The
+-- array ndx and val are not changed by the routine.
+--
+-- *Returns*
+--
+-- The routine lpx_eval_red_cost returns reduced cost (dual value) of
+-- the explicitly specified column computed in the assumption that this
+-- column has zero objective coefficient. If the objective coefficient
+-- of the specified column is non-zero, it should be added to the value
+-- returned by the routine.
+--
+-- *Algorithm*
+--
+-- By the definition reduced cost d of the structural variable x (*) is
+--
+--    d = c + pi * a,                                               (**)
+--
+-- where c is the objective coefficient of the variable x, pi is the
+-- vector of simplex multipliers (which are Lagrange multipliers for
+-- equality constraints), a is the column of the constraint matrix for
+-- the variable x.
+--
+-- *Unscaling*
+--
+-- Let A~ = (I | -A) is the augmented constraint matrix of the original
+-- (unscaled) problem. In the scaled LP problem instead the matrix A the
+-- scaled matrix A" = R*A*S is actually used, so
+--
+--    A~" = (I | A") = (I | R*A*S) = (R*I*inv(R) | R*A*S) =
+--                                                                   (1)
+--        = R*(I | A)*S~ = R*A~*S~,
+--
+-- is the scaled augmented constraint matrix, where R and S are diagonal
+-- scaling matrices used to scale rows and columns of the matrix A, and
+--
+--    S~ = diag(inv(R) | S)                                          (2)
+--
+-- is an augmented diagonal scaling matrix.
+--
+-- By the definition the vector pi is
+--
+--    pi = inv(B') * cB,                                             (3)
+--
+-- where cB is a subvector of objective coefficients at basic variables,
+-- B' is a matrix transposed to the basis matrix B.
+--
+-- For scaled components of the objective function we have
+--
+--    cR" = inv(R) * cR,
+--                                                                   (4)
+--    cS" = S * cS,
+--
+-- so
+--
+--    cB" = SB~ * cB,                                                (5)
+--
+-- where SB~ is a submatrix of the matrix S~ (2), which corresponds to
+-- basic variables. Therefore from (3) it follows:
+--
+--    pi" = inv(SB~*B'*R) * (SB~*cB) =
+--
+--        = inv(R) * inv(B') * inv(SB~) * sB~ * cB =                 (6)
+--
+--        = inv(R) * inv(B') * cB = inv(R) * pi,
+--
+-- that allows expressing us the original vector pi through the scaled
+-- vector pi" actually stored in the problem object:
+--
+--    pi = R * pi".                                                  (7)
+--
+-- The formula (7) is used by the routine for unscaling components of
+-- the vector pi. */
+
+double lpx_eval_red_cost(LPX *lp, int len, int ndx[], double val[])
+{     int m = lp->m;
+      double *rs = lp->rs;
+      double *pi = lp->pi;
+      int i, t;
+      double dj;
+      /* check the explicitly specified column */
+      if (!(0 <= len && len <= m))
+         fault("lpx_eval_red_cost: len = %d; invalid column length",
+            len);
+      for (t = 1; t <= len; t++)
+      {  i = ndx[t];
+         if (!(1 <= i && i <= m))
+            fault("lpx_eval_red_cost: ndx[%d] = %d; row number out of r"
+               "ange", t, i);
+      }
+      /* the current dual basic solution should exist */
+      if (lp->d_stat == LPX_D_UNDEF)
+         fault("lpx_eval_red_cost: current dual basic solution not exis"
+            "t");
+      /* compute reduced cost dj = pi * A[j] */
+      dj = 0.0;
+      for (t = 1; t <= len; t++)
+      {  i = ndx[t];
+         dj += (rs[i] * pi[i]) * val[t];
+      }
+      return dj;
+}
+
+/*----------------------------------------------------------------------
+-- lpx_reduce_form - reduce linear form.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- int lpx_reduce_form(LPX *lp, int len, int ndx[], double val[],
+--    double work[]);
+--
+-- *Description*
+--
+-- The routine lpx_reduce_form reduces the specified linear form:
+--
+--    f = a[1]*x[1] + a[2]*x[2] + ... + a[m+n]*x[m+n],               (1)
+--
+-- which includes auxiliary and structural variables, by substituting
+-- auxiliary variables x[1], ..., x[m] from equality constraints of the
+-- specified LP object, so the resultant linear form becomes expressed
+-- only through structural variables:
+--
+--    f' = a'[1]*x[m+1] + a'[2]*x[m+2] + ... + a'[n]*x[m+n].         (2)
+--
+-- On entry indices and numerical values of the coefficients of the
+-- specified linear form (1) should be placed in locations ndx[1], ...,
+-- ndx[len] and val[1], ..., val[len], respectively, where indices from
+-- 1 to m denote auxiliary variables, indices from m+1 to m+n denote
+-- structural variables.
+--
+-- On exit the routine stores column indices and coefficients of the
+-- resultant linear form (2) in locations ndx[1], ..., ndx[len'] and
+-- val[1], ..., val[len'], respectively, where 0 <= len' <= n is number
+-- of non-zero coefficients returned by the routine.
+--
+-- The working array work should have at least 1+n locations, where n
+-- is number of columns in the LP object. If work is NULL, the working
+-- array is allocated and freed internally by the routine.
+--
+-- *Returns*
+--
+-- The routine returns len', which is number of non-zero coefficients
+-- in the resultant linear form. */
+
+int lpx_reduce_form(LPX *lp, int len, int ndx[], double val[],
+      double _work[])
+{     int m = lp->m;
+      int n = lp->n;
+      double *rs = lp->rs;
+      int *A_ptr = lp->A->ptr;
+      int *A_len = lp->A->len;
+      int *A_ndx = lp->A->ndx;
+      double *A_val = lp->A->val;
+      int i, j, k, t, beg, end, ptr;
+      double aij, *work = _work;
+      /* allocate working array */
+      if (_work == NULL) work = ucalloc(1+n, sizeof(double));
+      for (j = 1; j <= n; j++) work[j] = 0.0;
+      /* walk through terms of the given linear form */
+      for (t = 1; t <= len; t++)
+      {  k = ndx[t];
+         if (!(1 <= k && k <= m+n))
+            fault("lpx_reduce_form: ndx[%d] = %d; ordinal number out of"
+               " range", t, k);
+         if (k <= m)
+         {  /* x[k] is auxiliary variable */
+            i = k;
+            /* substitute x[i] = a[i,1]*x[m+1] + ... + a[i,n]*x[m+n] */
+            beg = A_ptr[i];
+            end = beg + A_len[i] - 1;
+            for (ptr = beg; ptr <= end; ptr++)
+            {  j = A_ndx[ptr];
+               aij = A_val[ptr] / (rs[i] * rs[m+j]); /* unscale */
+               work[j] += val[t] * aij;
+            }
+         }
+         else
+         {  /* x[k] is structural variable */
+            j = k - m;
+            work[j] += val[t];
+         }
+      }
+      /* convert the resultant linear form to sparse format */
+      len = 0;
+      for (j = 1; j <= n; j++)
+      {  if (work[j] != 0.0)
+         {  len++;
+            ndx[len] = j;
+            val[len] = work[j];
+         }
+      }
+      /* free working array */
+      if (_work == NULL) ufree(work);
+      /* return to the calling program */
+      return len;
+}
+
+/*----------------------------------------------------------------------
+-- lpx_mixed_gomory - generate Gomory's mixed integer cut.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- int lpx_mixed_gomory(LPX *lp, int kind[], int len, int ndx[],
+--    double val[]);
+--
+-- *Description*
+--
+-- The routine lpx_mixed_gomory generates a Gomory's mixed integer cut
+-- for a given row of the simplex table.
+--
+-- The given row of the simplex table should be explicitly specified in
+-- the form:
+--
+--    y = alfa[1]*xN[1] + alfa[2]*xN[2] + ... + alfa[n]*xN[n]        (1)
+--
+-- where y is some basic structural variable of integer kind, whose
+-- value in the current basic solution is assumed to be fractional,
+-- xN[1], ..., xN[n] are non-basic variables, alfa[1], ..., alfa[n] are
+-- influence coefficient.
+--
+-- On entry indices (ordinal numbers) of non-basic variables, which
+-- have non-zero influence coefficients, should be placed in locations
+-- ndx[1], ..., ndx[len], where indices from 1 to m denote auxiliary
+-- variables and indices from m+1 to m+n denote structural variables,
+-- and the corresponding influence coefficients should be placed in
+-- locations val[1], ..., val[len]. These arrays can be computed using
+-- the routine lpx_eval_tab_row.
+--
+-- The array kind specifies kinds of structural variables. The location
+-- kind[0] is not used. If the flag kind[j], 1 <= j <= n, is zero, the
+-- j-th structural variable (not the variable xN[j]!) is continuous. If
+-- it is non-zero, the j-th structural variable is integer. This array
+-- is not changed by the routine.
+--
+-- The routine generates the Gomory's mixed integer cut in the form of
+-- an inequality constraint:
+--
+--    a[1]*x[m+1] + a[2]*x[m+2] + ... + a[n]*x[m+n] >= b,            (2)
+--
+-- where x[m+1], ..., x[m+n] are structural variables, a[1], ..., a[n]
+-- are constraint coefficients, b is a right-hand side.
+--
+-- On exit the routine stores indices of structural variables and the
+-- corresponding non-zero constraint coefficients for the inequality
+-- constraint (2) in locations ndx[1], ..., ndx[len'] and val[1], ...,
+-- val[len'], where 0 <= len' <= n is returned by the routine. The
+-- right-hand side b is stored to the location val[0], and the location
+-- ndx[0] is set to 0. (Should note than on exit indices of structural
+-- variables stored in the array ndx are in the range from 1 to n.)
+--
+-- The working array work should have at least 1+n locations, where n
+-- is number of columns in the LP object. If work is NULL, the working
+-- array is allocated and freed internally by the routine.
+--
+-- *Returns*
+--
+-- If the cutting plane has been successfully generated, the routine
+-- returns 0 <= len' <= n, which is number of non-zero coefficients in
+-- the inequality constraint (2). In case of errors the routine returns
+-- one of the following negative codes:
+--
+-- -1 - in the row (1) there is a free non-basic variable with non-zero
+--      influence coefficient;
+-- -2 - value of the basic variable y defined by the row (1) is near to
+--      a closest integer point, so the cutting plane may be unreliable.
+--
+-- *References*
+--
+-- 1. R.E.Gomory. An algorithm for the mixed integer problem. Tech.Rep.
+--    RM-2597, The RAND Corp. (1960).
+--
+-- 2. H.Marchand, A.Martin, R.Weismantel, L.Wolsey. Cutting Planes in
+--    Integer and Mixed Integer Programming. CORE, October 1999. */
+
+int lpx_mixed_gomory(LPX *lp, int kind[], int len, int ndx[],
+      double val[], double _work[])
+{     int m = lp->m;
+      int n = lp->n;
+      double *lb = lp->lb;
+      double *ub = lp->ub;
+      double *rs = lp->rs;
+      int *tagx = lp->tagx;
+      int *posx = lp->posx;
+      int *indx = lp->indx;
+      int j, k, t;
+      double *a, a_j, b, *alfa, alfa_j, beta, lb_k, ub_k, f0, fj;
+      double *work = _work;
+      /* allocate working array */
+      if (_work == NULL) work = ucalloc(1+n, sizeof(double));
+      /* on entry the specified row of the simplex table has the form:
+         y = alfa[1]*xN[1] + ... + alfa[n]*xN[n];
+         convert this row to the form:
+         y + alfa'[1]*xN'[1] + ... + alfa'[n]*xN'[n] = beta,
+         where all new (stroked) non-basic variables are non-negative
+         (this is not needed for y, because it has integer bounds and
+         only fractional part of beta is used); note that beta is the
+         value of y in the current basic solution */
+      alfa = work;
+      for (j = 1; j <= n; j++) alfa[j] = 0.0;
+      beta = 0.0;
+      for (t = 1; t <= len; t++)
+      {  /* get index of some non-basic variable x[k] = xN[j] */
+         k = ndx[t];
+         if (!(1 <= k && k <= m+n))
+            fault("lpx_mixed_gomory: ndx[%d] = %d; variable number out "
+               "of range", t, k);
+         if (tagx[k] == LPX_BS)
+            fault("lpx_mixed_gomory: ndx[%d] = %d; variable should be n"
+               "on-basic", t, k);
+         j = posx[k] - m; /* x[k] = xN[j] */
+         insist(1 <= j && j <= n);
+         insist(alfa[j] == 0.0);
+         /* get the original influence coefficient alfa[j] */
+         alfa_j = val[t];
+         /* obtain unscaled bounds of the variable x[k] = xN[j] */
+         if (k <= m)
+         {  lb_k = lb[k] / rs[k];
+            ub_k = ub[k] / rs[k];
+         }
+         else
+         {  lb_k = lb[k] * rs[k];
+            ub_k = ub[k] * rs[k];
+         }
+         /* perform conversion */
+         switch (tagx[k])
+         {  case LPX_NL:
+               /* xN[j] is on its lower bound */
+               /* substitute xN[j] = lb[k] + xN'[j] */
+               alfa[j] = - alfa_j;
+               beta += alfa_j * lb_k;
+               break;
+            case LPX_NU:
+               /* xN[j] is on its upper bound */
+               /* substitute xN[j] = ub[k] - xN'[j] */
+               alfa[j] = + alfa_j;
+               beta += alfa_j * ub_k;
+               break;
+            case LPX_NF:
+               /* xN[j] is free non-basic variable */
+               return -1;
+            case LPX_NS:
+               /* xN[j] is fixed non-basic variable */
+               /* substitute xN[j] = lb[k] */
+               alfa[j] = 0.0;
+               beta += alfa_j * lb_k;
+               break;
+            default:
+               insist(tagx != tagx);
+         }
+      }
+      /* now the converted row of the simplex table has the form:
+         y + alfa'[1]*xN'[1] + ... + alfa'[n]*xN'[n] = beta,
+         where all xN'[j] >= 0; generate Gomory's mixed integer cut in
+         the form of inequality:
+         a'[1]*xN'[1] + ... + a'[n]*xN'[n] >= b' */
+      a = work;
+      /* f0 is fractional part of beta, where beta is the value of the
+         variable y in the current basic solution; if f0 is close to
+         zero or to one, i.e. if y is near to a closest integer point,
+         the corresponding cutting plane may be unreliable */
+      f0 = beta - floor(beta);
+      if (!(0.00001 <= f0 && f0 <= 0.99999)) return -2;
+      for (j = 1; j <= n; j++)
+      {  alfa_j = alfa[j];
+         if (alfa_j == 0.0)
+         {  a[j] = 0.0;
+            continue;
+         }
+         k = indx[m+j]; /* x[k] = xN[j] */
+         insist(1 <= k && k <= m+n);
+         if (k > m && kind[k-m])
+         {  /* xN[j] is integer */
+            fj = alfa_j - floor(alfa_j);
+            if (fj <= f0)
+               a[j] = fj;
+            else
+               a[j] = (f0 / (1.0 - f0)) * (1.0 - fj);
+         }
+         else
+         {  /* xN[j] is continuous */
+            if (alfa_j > 0.0)
+               a[j] = alfa_j;
+            else
+               a[j] = - (f0 / (1.0 - f0)) * alfa_j;
+         }
+      }
+      b = f0;
+      /* now the generated cutting plane has the form of an inequality:
+         a'[1]*xN'[1] + ... + a'[n]*xN'[n] >= b';
+         convert this inequality back to the form expressed through the
+         original non-basic variables:
+         a[1]*xN[1] + ... + a[n]*xN[n] >= b */
+      len = 0;
+      for (j = 1; j <= n; j++)
+      {  /* get constraint coefficient at xN[j] */
+         a_j = a[j];
+         if (a_j == 0.0) continue;
+         k = indx[m+j]; /* x[k] = xN[j] */
+         /* obtain unscaled bounds of the variable x[k] = xN[j] */
+         if (k <= m)
+         {  lb_k = lb[k] / rs[k];
+            ub_k = ub[k] / rs[k];
+         }
+         else
+         {  lb_k = lb[k] * rs[k];
+            ub_k = ub[k] * rs[k];
+         }
+         /* perform conversion */
+         len++;
+         ndx[len] = k;
+         switch (tagx[k])
+         {  case LPX_NL:
+               /* xN[j] is on its lower bound */
+               /* substitute xN'[j] = xN[j] - lb[k] */
+               val[len] = + a_j;
+               b += a_j * lb_k;
+               break;
+            case LPX_NU:
+               /* xN[j] is on its upper bound */
+               /* substitute xN'[j] = ub[k] - xN[j] */
+               val[len] = - a_j;
+               b -= a_j * ub_k;
+               break;
+            default:
+               insist(tagx != tagx);
+         }
+      }
+      /* substitute auxiliary (non-basic) variables to the generated
+         inequality constraint a[1]*xN[1] + ... + a[n]*xN[n] >= b using
+         the equality constraints of the specified LP problem object in
+         order to express the generated constraint through structural
+         variables only */
+      len = lpx_reduce_form(lp, len, ndx, val, work);
+      /* store the right-hand side */
+      ndx[0] = 0, val[0] = b;
+      /* free working array */
+      if (_work == NULL) ufree(work);
+      /* return to the calling program */
+      return len;
+}
+
 /* eof */
