@@ -1507,10 +1507,9 @@ done: /* return to the factorizing routine */
 -- The routine luf_decomp returns one of the following codes:
 --
 -- 0 - no errors;
--- 1 - the given basis matrix is singular (on some elimination step all
---     elements of the active submatrix are zeros, due to that the pivot
---     can't be chosen);
--- 2 - the given basis matrix is ill-conditioned (on some elimination
+-- 1 - the given matrix is singular (on some elimination step the active
+--     submatrix is zero, due to that the pivot can't be chosen);
+-- 2 - the given matrix is probably ill-conditioned (on some elimination
 --     step too intensive growth of elements of the active submatrix has
 --     been detected).
 --
@@ -1642,7 +1641,7 @@ more: /* re-allocate the sparse vector area (if required) */
       }
       /* now the matrix U = P*V*Q is upper triangular, the matrix V has
          been built in row-wise format, and the matrix F has been built
-         in column-like format */
+         in column-wise format */
       /* defragment the sparse vector area in order to merge all free
          locations in one continous extent */
       luf_defrag_sva(luf);
@@ -1753,7 +1752,7 @@ void luf_f_solve(LUF *luf, int tr, double x[])
 --
 -- On entry the array x should contain elements of the right-hand side
 -- vector b in locations x[1], ..., x[n], where n is the order of the
--- matrix F. On exit this array will contain elements of the solution
+-- matrix V. On exit this array will contain elements of the solution
 -- vector x in the same locations. */
 
 void luf_v_solve(LUF *luf, int tr, double x[])
@@ -1770,6 +1769,8 @@ void luf_v_solve(LUF *luf, int tr, double x[])
       double *b = luf->work;
       int i, j, k, beg, end, ptr;
       double temp;
+      if (!luf->valid)
+         fault("luf_v_solve: LU-factorization is not valid");
       for (k = 1; k <= n; k++) b[k] = x[k], x[k] = 0.0;
       if (!tr)
       {  /* solve the system V*x = b */
@@ -1819,7 +1820,7 @@ void luf_v_solve(LUF *luf, int tr, double x[])
 --
 -- On entry the array x should contain elements of the right-hand side
 -- vector b in locations x[1], ..., x[n], where n is the order of the
--- matrix F. On exit this array will contain elements of the solution
+-- matrix A. On exit this array will contain elements of the solution
 -- vector x in the same locations. */
 
 void luf_solve(LUF *luf, int tr, double x[])
