@@ -26,6 +26,7 @@
 #include <float.h>
 #include <math.h>
 #include <stddef.h>
+#include "glplib.h"
 #include "glpmat.h"
 
 /*----------------------------------------------------------------------
@@ -389,7 +390,7 @@ MAT *clear_line(MAT *A, int k)
                insist(f != NULL);
                f->col = e->col;
             }
-            free_atom(A->pool, e);
+            dmp_free_atom(A->pool, e);
          }
          A->row[i] = NULL;
       }
@@ -409,7 +410,7 @@ MAT *clear_line(MAT *A, int k)
                insist(f != NULL);
                f->row = e->row;
             }
-            free_atom(A->pool, e);
+            dmp_free_atom(A->pool, e);
          }
          A->col[j] = NULL;
       }
@@ -471,7 +472,7 @@ MAT *clear_lines(MAT *A, int rs[], int cs[])
             {  e = A->col[j];
                A->col[j] = e->col;
                if (rs[e->i])
-                  free_atom(A->pool, e);
+                  dmp_free_atom(A->pool, e);
                else
                   e->col = ptr, ptr = e;
             }
@@ -488,7 +489,7 @@ MAT *clear_lines(MAT *A, int rs[], int cs[])
             {  e = A->row[i];
                A->row[i] = e->row;
                if (cs[e->j])
-                  free_atom(A->pool, e);
+                  dmp_free_atom(A->pool, e);
                else
                   e->row = ptr, ptr = e;
             }
@@ -521,7 +522,7 @@ MAT *clear_lines(MAT *A, int rs[], int cs[])
 
 MAT *clear_mat(MAT *A)
 {     int i, j;
-      clear_pool(A->pool);
+      dmp_free_all(A->pool);
       for (i = 1; i <= A->m; i++) A->row[i] = NULL;
       for (j = 1; j <= A->n; j++) A->col[j] = NULL;
       return A;
@@ -663,7 +664,7 @@ MAT *create_mat(int m, int n)
       if (!(m >= 0 && n >= 0))
          fault("create_mat: m = %d, n = %d; invalid dimension", m, n);
       A = umalloc(sizeof(MAT));
-      A->pool = create_pool(sizeof(ELEM));
+      A->pool = dmp_create_pool(sizeof(ELEM));
       while (m_max < m) m_max += m_max, insist(m_max > 0);
       while (n_max < n) n_max += n_max, insist(n_max > 0);
       A->m_max = m_max;
@@ -790,7 +791,7 @@ MAT *delete_lines(MAT *A, int rs[], int cs[])
 -- allocated to this object. */
 
 void delete_mat(MAT *A)
-{     delete_pool(A->pool);
+{     dmp_delete_pool(A->pool);
       ufree(A->row);
       ufree(A->col);
       ufree(A);
@@ -1422,7 +1423,7 @@ ELEM *new_elem(MAT *A, int i, int j, double val)
 {     ELEM *e;
       if (!(1 <= i && i <= A->m && 1 <= j && j <= A->n))
          fault("new_elem: row or column number out of range");
-      e = get_atom(A->pool);
+      e = dmp_get_atom(A->pool);
       e->i = i; e->j = j; e->val = val;
       e->row = A->row[i]; e->col = A->col[j];
       A->row[i] = A->col[j] = e;
@@ -1615,7 +1616,7 @@ int scrape_mat(MAT *A, double eps)
          while (A->col[j] != NULL)
          {  e = A->col[j], A->col[j] = e->col;
             if (e->val == 0.0)
-               free_atom(A->pool, e);
+               dmp_free_atom(A->pool, e);
             else
                e->col = ee, ee = e;
          }
